#!/usr/bin/env python
# -*-coding:utf-8 -*-
"""

@Author  :   Jeremy Bleyer, Ecole des Ponts ParisTech, Navier
@Contact :   jeremy.bleyer@enpc.fr
@Time    :   26/05/2023
"""
import numpy as np
import matplotlib.pyplot as plt
from damage_gradient import solve_problem
from mealor.utils import plot_over_line

L = 1.0
H = 0.1
mesh, cell_markers, facet_markers = generate_homog(1)

E = 3.0e3
nu = 0.3
# KIc = 1.4 * np.sqrt(1e3)
# Gc = (1 - nu**2) / E * KIc**2
Gc = 3e-3
l0 = 0.1
model = "AT1"
Nincr = 10
Umax = 2e-2
mech_params = (E, nu, Gc, l0, model, Umax, Nincr)
prob_params = (False, True, 100, 1e-6)
results, u, d, sig = solve_problem(
    mesh, cell_markers, facet_markers, prob_params, mech_params
)

line = [(0.01, H / 2), (0.99, H / 2)]
dv, points = plot_over_line(d, line, mesh)
x = points[:, 0]
plt.plot(x, dv, "-", label="damage profile")
plt.xlabel("x")
plt.ylabel("Damage")
plt.plot(x, np.exp(np.abs(x - L / 2) / l0), "--r", label="theoretical profile")
plt.legend()

# print(points[:, 0], dv)
# plt.savefig("test.pdf")
# plt.show()
